@@ -5,12 +5,9 @@
 
 // [[export]]
 SEXP agg_jpeg_c(SEXP file, SEXP width, SEXP height, SEXP pointsize, SEXP bg, 
-                SEXP res, SEXP scaling, SEXP quality, SEXP smoothing, 
+                SEXP res, SEXP scaling, SEXP snap, SEXP quality, SEXP smoothing, 
                 SEXP method) {
   int bgCol = RGBpar(bg, 0);
-  if (R_TRANSPARENT(bgCol)) {
-    bgCol = R_TRANWHITE;
-  }
   
   BEGIN_CPP
     AggDeviceJpegNoAlpha* device = new AggDeviceJpegNoAlpha(
@@ -21,6 +18,7 @@ SEXP agg_jpeg_c(SEXP file, SEXP width, SEXP height, SEXP pointsize, SEXP bg,
       bgCol,
       REAL(res)[0],
       REAL(scaling)[0],
+      LOGICAL(snap)[0],
       INTEGER(quality)[0],
       INTEGER(smoothing)[0],
       INTEGER(method)[0]
