@@ -5,7 +5,7 @@
 
 // [[export]]
 SEXP agg_png_c(SEXP file, SEXP width, SEXP height, SEXP pointsize, SEXP bg, 
-               SEXP res, SEXP scaling, SEXP bit) {
+               SEXP res, SEXP scaling, SEXP snap, SEXP bit) {
   bool bit8 = INTEGER(bit)[0] == 8;
   int bgCol = RGBpar(bg, 0);
   
@@ -19,7 +19,8 @@ SEXP agg_png_c(SEXP file, SEXP width, SEXP height, SEXP pointsize, SEXP bg,
         REAL(pointsize)[0], 
         bgCol,
         REAL(res)[0],
-        REAL(scaling)[0]
+        REAL(scaling)[0],
+        LOGICAL(snap)[0]
       );
       makeDevice<AggDevicePngNoAlpha>(device, "agg_png");
     } else {
@@ -30,7 +31,8 @@ SEXP agg_png_c(SEXP file, SEXP width, SEXP height, SEXP pointsize, SEXP bg,
         REAL(pointsize)[0], 
         bgCol,
         REAL(res)[0],
-        REAL(scaling)[0]
+        REAL(scaling)[0],
+        LOGICAL(snap)[0]
       );
       makeDevice<AggDevicePngAlpha>(device, "agg_png");
     }
@@ -43,7 +45,8 @@ SEXP agg_png_c(SEXP file, SEXP width, SEXP height, SEXP pointsize, SEXP bg,
         REAL(pointsize)[0], 
         bgCol,
         REAL(res)[0],
-        REAL(scaling)[0]
+        REAL(scaling)[0],
+        LOGICAL(snap)[0]
       );
       makeDevice<AggDevicePng16NoAlpha>(device, "agg_png");
     } else {
@@ -54,7 +57,8 @@ SEXP agg_png_c(SEXP file, SEXP width, SEXP height, SEXP pointsize, SEXP bg,
         REAL(pointsize)[0], 
         bgCol,
         REAL(res)[0],
-        REAL(scaling)[0]
+        REAL(scaling)[0],
+        LOGICAL(snap)[0]
       );
       makeDevice<AggDevicePng16Alpha>(device, "agg_png");
     }
@@ -65,7 +69,8 @@ SEXP agg_png_c(SEXP file, SEXP width, SEXP height, SEXP pointsize, SEXP bg,
 }
 
 SEXP agg_supertransparent_c(SEXP file, SEXP width, SEXP height, SEXP pointsize, 
-                            SEXP bg, SEXP res, SEXP scaling, SEXP alpha_mod) {
+                            SEXP bg, SEXP res, SEXP scaling, SEXP snap, 
+                            SEXP alpha_mod) {
   int bgCol = RGBpar(bg, 0);
   
   BEGIN_CPP
@@ -78,6 +83,7 @@ SEXP agg_supertransparent_c(SEXP file, SEXP width, SEXP height, SEXP pointsize,
       bgCol,
       REAL(res)[0],
       REAL(scaling)[0],
+      LOGICAL(snap)[0],
       REAL(alpha_mod)[0]
     );
     makeDevice<AggDevicePng16NoAlpha>(device, "agg_png");
@@ -90,6 +96,7 @@ SEXP agg_supertransparent_c(SEXP file, SEXP width, SEXP height, SEXP pointsize,
       bgCol,
       REAL(res)[0],
       REAL(scaling)[0],
+      LOGICAL(snap)[0],
       REAL(alpha_mod)[0]
     );
     makeDevice<AggDevicePng16Alpha>(device, "agg_png");
