@@ -5,7 +5,7 @@
 
 // [[export]]
 SEXP agg_ppm_c(SEXP file, SEXP width, SEXP height, SEXP pointsize, SEXP bg, 
-               SEXP res, SEXP scaling) {
+               SEXP res, SEXP scaling, SEXP snap) {
   int bgCol = RGBpar(bg, 0);
   if (R_TRANSPARENT(bgCol)) {
     bgCol = R_TRANWHITE;
@@ -19,7 +19,8 @@ SEXP agg_ppm_c(SEXP file, SEXP width, SEXP height, SEXP pointsize, SEXP bg,
     REAL(pointsize)[0], 
     bgCol,
     REAL(res)[0],
-    REAL(scaling)[0]
+    REAL(scaling)[0],
+    LOGICAL(snap)[0]
   );
   makeDevice<AggDevicePpmNoAlpha>(device, "agg_ppm");
   END_CPP
